.. Beginner Friendly Riot API Caller (bfrac) documentation master file, created by
   sphinx-quickstart on Mon Apr 17 05:55:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Beginner Friendly Riot API Caller (bfrac)'s documentation!
=====================================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   usage



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
